"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Webhook = void 0;
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
class Webhook {
    constructor(webhookUrl) {
        this.client = axios_1.default.create({
            baseURL: webhookUrl,
        });
    }
    setUsername(username) {
        this.username = username;
        return this;
    }
    setAvatarUrl(url) {
        this.avatar_url = url;
        return this;
    }
    setTTS(flag) {
        this.tts = flag;
        return this;
    }
    setContent(content) {
        this.content = content;
        return this;
    }
    setEmbed(embed) {
        var _a;
        (_a = this.embeds) === null || _a === void 0 ? void 0 : _a.push(embed.toObject());
        return this;
    }
    setFile(file) {
        this.file = file;
        return this;
    }
    send() {
        return this.client.request({
            method: 'POST',
            data: this.toObject(),
        });
    }
    modify(options) {
        return this.client.request({
            method: 'PATCH',
            data: options,
        });
    }
    get() {
        return this.client.request({
            method: 'GET',
        });
    }
    isValid() {
        return this.get()
            .then(() => true)
            .catch(() => false);
    }
    toObject() {
        return {
            username: this.username,
            avatar_url: this.avatar_url,
            tts: this.tts,
            content: this.content,
            file: this.file,
            embeds: this.embeds,
        };
    }
}
exports.Webhook = Webhook;
//# sourceMappingURL=Webhook.js.map